@@ -194,7 +194,7 @@ class Object():
             self.__dict__.update(response)
 
         ##if guid not provided          and errors provided     and "unable to read" error code in error list       and there's a name to search by
-        elif "guid" not in response and "errors" in response and 3124 in [x['code'] for x in response[errors]] and "name" in data:
+        elif "guid" not in response and "errors" in response and 3124 in [x['code'] for x in response['errors']] and "name" in data:
             print("Delayed creation, using name search and waiting up to 15s for data....")
             results=[]
             i=0
@@ -256,6 +256,23 @@ class Object():
     @lazy
     def user(self):
         return self._client.User(self.creator['guid'])
+
+    @property
+    def json(self):
+
+        def process_values(x):
+            if isinstance(x, Object):
+                return x.json
+            else:
+                return x
+
+        data={x:process_values(self.__dict__[x]) for x in self.__dict__}
+
+        data.pop("_client")
+        data.pop("_cache")
+
+        return data
+    
     
 class openable_mixin():
 
